# Script to brute force an md5 hash.

This script is for brute forcing your way through an md5 hash. Install the package using pip, run the script, paste your hash -> done.

# How to use:
To install `md5-brute-force` using `pip`:
```
pip install md5-brute-force
```

To execute the script enter:
```
md5-brute-force
```

# How does it work?
![md5-brute-force](https://github.com/vsevolod-mineev/md5-brute-force/blob/main/images/md5-brute-force-image.png?raw=true)

